@@ -29,6 +29,7 @@
 #include <gpe/spacing.h>
 #include <gpe/schedule.h>
 #include <gpe/pim-categories.h>
+#include <gpe/pim-categories-ui.h>
 
 #include "globals.h"
 #include "event-ui.h"
@@ -242,9 +243,8 @@ edit_finished (GtkWidget *d)
 }
 
 static void
-click_delete (GtkWidget *widget, GtkWidget *dw)
+click_delete (GtkWidget *widget, GtkWidget *d)
 {
-  GtkWidget *d = gtk_widget_get_toplevel (widget);
   struct edit_state *s = g_object_get_data (G_OBJECT (d), "edit_state");
   event_t ev = s->ev, ev_real;
   event_details_t ev_d;
@@ -1330,8 +1330,8 @@ edit_event (event_t ev)
       gtk_widget_set_sensitive (s->deletebutton, TRUE);
       evd = event_db_get_details (ev);
       gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (s->description)),
-                                evd->description, -1);
-      gtk_entry_set_text (GTK_ENTRY (s->summary), evd->summary);
+				evd->description ? evd->description : "", -1);
+      gtk_entry_set_text (GTK_ENTRY (s->summary), evd->summary ? evd->summary : "");
       event_db_forget_details (ev);
 
       localtime_r (&(ev->start), &tm);
